import { 
    select, 
    csv, 
    scaleLinear, 
    extent, 
    axisLeft,
    axisBottom,
  	format
} from 'd3'

const svg = select('svg')
const height = +svg.attr('height');//parseFloat
const width = +svg.attr('width');
const title = 'Cars:horsepower vs. weight';

//d.mpg = +d.mpg;
//d.cylinders = +d.cylinders;
//d.displacement = +d.displacement;
//d.horsepower = +d.horsepower;
//d.weight = +d.weight;
//d.acceleration = +d.acceleration;
//d.year = +d.year;

const render = data=> {
    const xValue = d => d.horsepower;
  	const XAxislabel = 'Horsepower';
  
    const yValue = d => d.weight;
  	const YAxislabel = 'weight';
  	
  	const Radius = 10;
    const margin={top: 50, right: 40, bottom: 75, left: 150};
    const innerwidth= width-margin.left-margin.right;
    const innerheight= height-margin.top-margin.bottom;

    const xScale = scaleLinear()
        .domain(extent(data, xValue))
        .range([0, innerwidth])
    		.nice();

    const yScale = scaleLinear()
        .domain(extent(data, yValue))
        .range([0, innerheight])
  			.nice();

//the margin convention
    const g = svg.append('g')
        .attr('transform', `translate(${margin.left},${margin.top})`);
  	const xAxisTickFormat = number => 
    	format('.3s')(number)
    		.replace('G','B');
  
  	const xAxis = axisBottom(xScale)
    		.tickSize(-innerheight)
    		.tickFormat(xAxisTickFormat)
  			.tickPadding(15);
  
  	const yAxis = axisLeft(yScale)
    		.tickSize(-innerwidth)
    		.tickPadding(10);
    //adding axis
   	const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();//remove unnecessary lines
  	//selectAll can choose more than one thing comparing with the select
  			
 	 	yAxisG.append('text')
  		.attr('class','axis-label')
  		.attr('y',-90)
  		.attr('x',-innerheight / 2)
  		.attr('fill','black')
  		.attr('transform', `rotate(-90)`)
  		.attr('text-anchor','middle')
  		.text(YAxislabel);
  
    const xAxisG = g.append('g').call(xAxis)
        .attr('transform', `translate(0,${innerheight})`);
  	xAxisG.select('.domain').remove();
  	xAxisG.append('text')
  		.attr('class','axis-label')
  		.attr('y',65)
  		.attr('x',innerwidth/2)
  		.attr('fill','black')
  		.text(XAxislabel);

    g.selectAll('circle').data(data)//create a D3 data join
     .enter().append('circle')
     .attr('cy', d=> yScale(yValue(d)))
  	 .attr('cx',d => xScale(xValue(d)))
  	 .attr('r',Radius);
  
  	g.append('text')
  		.attr('class','title-label')
  		.attr('y', -10)
  		.text(title);
};

csv('https://vizhub.com/curran/datasets/auto-mpg.csv')
	.then(
  data => {
    data.forEach(d => {
      d.mpg = +d.mpg;
      d.cylinders = +d.cylinders;
      d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.weight = +d.weight;
      d.acceleration = +d.acceleration;
      d.year = +d.year;
    });
    render(data);
  })